/**
 * Functions generating animations on textures.
 *  
 * @author Michał Urbański (tajnyprojekt.com)
 * MIT license
 * 2020
 */

void drawStrobo(int gIndex) {
  PGraphics g = textures[gIndex];
  g.beginDraw();
  g.background(random(255));
  g.endDraw();
}

void drawFeedback(int gIndex) {
 PGraphics g = textures[gIndex];
 g.beginDraw();
 g.image(g, - 4, - 4, g.width + 8, g.height + 8);
 g.strokeWeight(3);
 g.stroke(((frameCount / 4) % 2) * 255);
 g.fill(0);
 float arg = ((frameCount / 3.0) % 100 / 100.0) * TWO_PI;
 g.rect(sin(arg) * 10 + g.width / 2 - 30, 
         cos(arg) * 10 + g.height / 2 - 30, 
         60, 60);
 g.endDraw();
}

void drawGlitch(int gIndex) {
  PGraphics g = textures[gIndex];
  float alpha = noise(frameCount / 100.0) * 0.07;
  g.beginDraw();     
  g.loadPixels();
  noiseSeed(gIndex);
  noiseDetail(8, 0.01);
  float xoff = 0.3 * sin(frameCount / 80.0);
  float inc = 0.002;
  for (int x = 0; x < g.width; x++) {
      xoff += inc;
      float yoff = 0.3 * cos(frameCount / 90.0);
      for (int y = 0; y < g.height; y++) {
        yoff += inc;
        int i = x + y * g.width;
        g.pixels[i] = color(noise(xoff, yoff) * 255);
      }
  }
  g.pixels[0] = (int)(alpha * g.pixels[0]);
  for (int i = 1; i < g.pixels.length; i++) {
      g.pixels[i] = (int)(g.pixels[i - 1] + alpha * (g.pixels[i] - g.pixels[i - 1]));
  }
  g.updatePixels();
  g.endDraw();
}